@@ -4,23 +4,31 @@ use strict;
 use warnings;
 use DBI;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 sub import {
 	my $self = shift;
 	my $args = { @_ };
 	
-	my $dbh = DBI->connect($args->{dsn},$args->{username},$args->{password})
-		or die "Couldn't establish connection to database via $args->{dsn}: $DBI::errstr";
-	
 	# Fetch the driver
 	my ($driver) = $args->{dsn} =~ m|^dbi:(.*?):.*$|;
+
+	# Get the tables
+	my @tables = ();
+	if(defined $args->{tables}) {
+		@tables = @{ $args->{tables} };
+	}
+	else {
+		my $dbh = DBI->connect($args->{dsn},$args->{username},$args->{password})
+			or die "Couldn't establish connection to database via $args->{dsn}: $DBI::errstr";
+		@tables = $dbh->tables();
+		$dbh->disconnect;
+	}
 	
 	# Generate the classes
-	foreach my $table ($dbh->tables) {
+	foreach my $table (@tables) {
 		generateClass($table,$driver,$args);
 	}
-	$dbh->disconnect;
 }
 
 sub table2class {
@@ -73,10 +81,12 @@ Class::DBI::AutoLoader - Generates Class::DBI subclasses dynamically.
   	username  => 'username',
   	password  => 'passw0rd',
   	options   => { RaiseError => 1 },
-  	namespace => 'Data'
+	tables    => ['favorite_films','directors']
+  	namespace => 'Films'
   );
   
-  my $row = Data::FavoriteFilms->retrieve(1);
+  my $film = Films::FavoriteFilms->retrieve(1);
+  my $dir  = Films::Directors( film => $film->id() );
 
 =head1 DESCRIPTION
 
@@ -122,6 +132,11 @@ The password for the database.
 A hashref of options such as you'd pass to the DBI->connect() method.
 This can contain any option that is valid for your database.
 
+=item * tables
+
+An array reference of table names to load. If you leave this option
+out, all tables in the database will be loaded.
+
 =item * namespace
 
 The master namespace you would like your packages declared in. See the
@@ -167,6 +182,11 @@ Please see L<Class::DBI::AbstractSearch> for full details
 Put your use Class::DBI::AutoLoader(...) call in your startup.pl file. Then
 all your mod_perl packages can use the generated classes directly.
 
+=head2 USE IN CGIs
+
+If you don't use the C<tables> option and you don't need all of the tables
+in the database, you're going to take an unneccessary penalty.
+
 =head2 WRAP IT IN A SUBCLASS
 
 You probably want to wrap this in a subclass so you don't have to go through
@@ -174,6 +194,38 @@ all of the dsn, user, blah blah everytime you use it. Additionally, you can
 put any __PACKAGE__->set_sql(...) type stuff in your subclass. That's helpful
 since you can't edit the generated classes.
 
+=head2 USING A SUBCLASS FOR CGIs
+
+ package My::DBI::ForCGI;
+ 
+ sub import {
+     my ($self,@tables) = @_;
+     require DBI::Class::AutoLoader;
+     DBI::Class::AutoLoader->import(
+         dsn => 'dbi:mysql:application',
+		 username => 'joe',
+		 password => 'friday',
+		 options => { RaiseError => 1 },
+		 tables => \@tables,
+		 namespace => 'My::DBI::ForCGI'
+     );
+ }
+ 1;
+
+Then in your CGI:
+
+ use strict;
+ use CGI;
+ use My::DBI::ForCGI ( tables => 'users' );
+
+ my $cgi = CGI->new();
+ my $user = My::DBI::ForCGI::Users->retrieve( $cgi->param('user_id') );
+ ...
+
+Since your classes are scanned and generated, you will always take some
+performance hit, especially when used in non-persistant environments like
+a CGI application. Use C<tables> liberally.
+ 
 =head1 SEE ALSO
 
 L<Class::DBI>, L<Class::DBI::mysql>, L<Class::DBI::Pg>, L<Class::DBI::SQLite>
